function GUI_EAGD
%-------------------------------------------------------------------------%
% Graphical user interface for pre- and post processors
%-------------------------------------------------------------------------%
%
% Programming by Arnkjell Loekke
% UCB / NTNU 2013
% email: lokke@stud.ntnu.no
% 
% Based on scripts provided by Baris Binici at the 
% Middle East Technical University (METU) 2013
%
%-------------------------------------------------------------------------%
% User is referred to users manual (pdf) for details on selection of 
% input parameters, etc.
%
%-------------------------------------------------------------------------%
%-------------------------------------------------------------------------%
%
%                           PRESS F5 TO RUN SCRIPT
%
%-------------------------------------------------------------------------%
%-------------------------------------------------------------------------%
%
%-------------------------------------------------------------------------%
%                                 DISCLAIMER
%-------------------------------------------------------------------------%
% THESE SCRIPTS ARE PROVIDED "AS IS" WITHOUT WARRANTIES OF ANY KIND. 
% THE AUTHOR MAKES NO GUARANTEES THAT THEY ARE FREE OF ERROR, OR THAT 
% THEY WILL MEET YOUR REQUIREMENTS FOR ANY PARTICULAR APPLICATION.
% THEY SHOULD NOT BE RELIED ON FOR SOLVING A PROBLEM WHOSE INCORRECT
% SOLUTION COULD RESULT IN LOSS OF LIFE OR PROPERTY. IF YOU DO USE THEM 
% IN SUCH A MANNER, IT IS AT YOUR OWN RISK. THE AUTHOR DISCLAIM ALL 
% LIABILITY FOR DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES RESULTING
% FROM YOUR USE OF THE SCRIPTS.
%-------------------------------------------------------------------------%
%

clc
clear all
close all force

%% 0. SELECTION OF UNIT SYSTEM
% Initialize figure to choose units
fI.h = figure('Visible','off','MenuBar','none','numbertitle','off','Toolbar','none','Position',[50,300,300,50]);
% UI Controls for units
h.UNITSpm = uicontrol('Style','popupmenu','String',{'S.I. units (m, MPa, kg/m3','Imperial units (ft, ksf, k-s2/ft4)'},'Value',1,'Position',[10,5,200,30],'Callback',{@UNITSpm_Callback});
h.DONEpb = uicontrol('Style','pushbutton','String','Ok','Units','pixels','Position',[230,10,50,30],'Callback',{@DONE1pb_Callback});
% Assign a GUI Name to appear in the window title.
set(fI.h,'Name','Select Unit System')
% Move the GUI to the center of the screen.
movegui(fI.h,'center')
% Make the GUI visible.
set(fI.h,'Visible','on');

% Set default values for units
unitSI = 1;
unitTick = '(in m)';
unitTick2 = 'Mod. of elasticity (in MPa)';
unitTick3 = 'Mass density (in kg/m3)';

% UNITSpm callback
function UNITSpm_Callback(source,eventdata)
    val = get(source,'Value');
    if val ~= 1
        unitSI = 0;
        unitTick = '(in ft)';
        unitTick2 = 'Mod. of elasticity (in ksf)';
        unitTick3 = 'Mass density (in k-s2/ft4)';
    end
end
% DONE callback
function DONE1pb_Callback(source,eventdata)
    close
end

% Wait until user has selected option before continuing
uiwait;

%% 1. CREATE GUI FOR PARAMETER SELECTION
f.h = figure('Visible','off','MenuBar','none','numbertitle','off','Toolbar','none','Position',[50,300,1024,576]);

% 1.1 CONSTRUCT EACH COMPONENT

% UI to show dam cross-section figure
h.dam_mod = axes('Units','Pixels','Position',[30,230,350,336]);
image(imread('DamProfile.jpg')); axis off
h.dam_modst = uicontrol('Style','text','String','*The typical dam cross-section above is given schematically','Units','pixels','Position',[10,205,390,15]);

% UI controls for dam material properties
matprop.h = uipanel('Parent',f.h,'Title','Dam Properties','Units','pixels','Position',[10,10,190,180]);
h.Eced = uicontrol(matprop.h,'Style','edit','String',unitTick2,'Units','pixels','Position',[50,130,125,20],'Callback',{@Eced_Callback});
h.Ecst = uicontrol(matprop.h,'Style','text','String','       Ec = ','Units','pixels','Position',[5,127.5,45,20]);
h.DENSced = uicontrol(matprop.h,'Style','edit','String',unitTick3,'Units','pixels','Position',[50,100,125,20],'Callback',{@DENSced_Callback});
h.DENScst = uicontrol(matprop.h,'Style','text','String','DENSc = ','Units','pixels','Position',[5,97.5,45,20]);
h.POISced = uicontrol(matprop.h,'Style','edit','String','Poissons ratio','Units','pixels','Position',[50,70,125,20],'Callback',{@POISced_Callback});
h.POIScst = uicontrol(matprop.h,'Style','text','String','POISc = ','Units','pixels','Position',[5,67.5,45,20]);
h.DAMPced = uicontrol(matprop.h,'Style','edit','String','Hysteretic damping factor','Units','pixels','Position',[50,40,125,20],'Callback',{@DAMPced_Callback});
h.DAMPcst = uicontrol(matprop.h,'Style','text','String','DAMPc*','Units','pixels','Position',[5,37.5,45,20]);
h.DAMPcst2 = uicontrol(matprop.h,'Style','text','String','*DAMPc : Hysteretic damping factor for dam concrete','Units','pixels','Position',[5,10,170,25]);
set(h.DAMPcst2,'FontAngle','italic');

% UI controls for foundation properties
fndprop.h = uipanel('Parent',f.h,'Title','Foundation Rock Properties','Units','pixels','Position',[210,10,190,180]);
h.Efed = uicontrol(fndprop.h,'Style','edit','String',unitTick2,'Units','pixels','Position',[50,130,125,20],'Callback',{@Efed_Callback});
h.Efst = uicontrol(fndprop.h,'Style','text','String','       Ef = ','Units','pixels','Position',[2.5,125.5,45,20]);
h.DENSfed = uicontrol(fndprop.h,'Style','edit','String',unitTick3,'Units','pixels','Position',[50,100,125,20],'Callback',{@DENSfed_Callback});
h.DENSfst = uicontrol(fndprop.h,'Style','text','String','DENSf = ','Units','pixels','Position',[2.5,97.5,45,20]);
h.DAMPfpm = uicontrol(fndprop.h,'Style','popupmenu','String',{'0.01','0.02','0.03','0.04','0.05','0.06','0.07','0.08','0.09','0.10', ...
                      '0.12','0.14','0.16','0.18','0.20','0.25','0.50'},'Value',1,'Position',[50,70,125,20],'Callback',{@DAMPfpm_Callback});
h.DAMPfst = uicontrol(fndprop.h,'Style','text','String','DAMPf*','Units','pixels','Position',[2.5,67.5,45,20]);
h.DAMPfst2 = uicontrol(fndprop.h,'Style','text','String','*DAMPf : Hysteretic damping factor for foundation','Units','pixels','Position',[5,37.5,170,25]);
set(h.DAMPfst2,'FontAngle','italic');
h.nBASEed = uicontrol(fndprop.h,'Style','edit','String','# of base nodal points','Units','pixels','Position',[50,10,125,20],'Callback',{@nBASEed_Callback});
h.nBASEst = uicontrol(fndprop.h,'Style','text','String','NBASE =','Units','pixels','Position',[2.5,7.5,45,20]);

% UI Controls for geometric properties
geoprop.h = uipanel('Parent',f.h,'Title','Geometric Properties of Dam','Units','pixels','Position',[410,356,210,210]);
h.elAed = uicontrol(geoprop.h,'Style','edit','String',unitTick,'Units','pixels','Position',[80,170,50,20],'Callback',{@elAed_Callback});
h.elAst = uicontrol(geoprop.h,'Style','text','String','elev. A = ','Units','pixels','Position',[10,167.5,50,20]);
h.elBed = uicontrol(geoprop.h,'Style','edit','String',unitTick,'Units','pixels','Position',[80,145,50,20],'Callback',{@elBed_Callback});
h.elBst = uicontrol(geoprop.h,'Style','text','String','elev. B =','Units','pixels','Position',[10,142.5,50,20]);
h.elCed = uicontrol(geoprop.h,'Style','edit','String',unitTick,'Units','pixels','Position',[80,120,50,20],'Callback',{@elCed_Callback});
h.elCst = uicontrol(geoprop.h,'Style','text','String','elev. C =','Units','pixels','Position',[10,117.5,50,20]);
h.elDed = uicontrol(geoprop.h,'Style','edit','String',unitTick,'Units','pixels','Position',[80,95,50,20],'Callback',{@elDed_Callback});
h.elDst = uicontrol(geoprop.h,'Style','text','String','elev. D =','Units','pixels','Position',[10,92.5,50,20]);
h.elWLed = uicontrol(geoprop.h,'Style','edit','String',unitTick,'Units','pixels','Position',[80,70,50,20],'Callback',{@elWLed_Callback});
h.elWLst = uicontrol(geoprop.h,'Style','text','String','elev. WL =','Units','pixels','Position',[10,67.5,60,20]);
h.L1ed = uicontrol(geoprop.h,'Style','edit','String',unitTick,'Units','pixels','Position',[40,45,50,20],'Callback',{@L1ed_Callback});
h.L1st = uicontrol(geoprop.h,'Style','text','String','L1 =','Units','pixels','Position',[5,42.5,30,20]);
h.L2ed = uicontrol(geoprop.h,'Style','edit','String',unitTick,'Units','pixels','Position',[140,45,50,20],'Callback',{@L2ed_Callback});
h.L2st = uicontrol(geoprop.h,'Style','text','String','L2 =','Units','pixels','Position',[105,42.5,30,20]);
h.L3ed = uicontrol(geoprop.h,'Style','edit','String',unitTick,'Units','pixels','Position',[40,20,50,20],'Callback',{@L3ed_Callback});
h.L3st = uicontrol(geoprop.h,'Style','text','String','L3 =','Units','pixels','Position',[5,17.5,30,20]);
h.L4ed = uicontrol(geoprop.h,'Style','edit','String',unitTick,'Units','pixels','Position',[140,20,50,20],'Callback',{@L4ed_Callback});
h.L4st = uicontrol(geoprop.h,'Style','text','String','L4 =','Units','pixels','Position',[105,17.5,30,20]);

% UI controls for dynamic response parameters
dynparam.h = uipanel('Parent',f.h,'Title','Dynamic Response Parameters','Units','pixels','Position',[410,81,210,160]);
h.readEQpb = uicontrol(dynparam.h,'Style','pushbutton','String','Define Ground Motion Input File','Position',[5,110,192.5,30],'Callback',{@readEQpb_Callback});
h.IHVpm = uicontrol(dynparam.h,'Style','popupmenu','String',{'Response due to horizontal ground motion component','Response due to vertical ground motion component','Response due to horizontal & vertical ground motion components'},'Value',1,'Position',[55,85,140,20],'Callback',{@IHVpm_Callback});
h.IHVst = uicontrol(dynparam.h,'Style','text','String','  IHV = ','Units','pixels','Position',[5,82.5,45,20]);
h.NEVed = uicontrol(dynparam.h,'Style','edit','String','# of Ritz vectors (def.=12)','Units','pixels','Position',[55,60,140,20],'Callback',{@NEVed_Callback});
h.NEVst = uicontrol(dynparam.h,'Style','text','String','NEV = ','Units','pixels','Position',[5,57.5,45,20]);
h.NEXPed = uicontrol(dynparam.h,'Style','edit','String','FFT parameter','Units','pixels','Position',[55,35,140,20],'Callback',{@NEXPed_Callback});
h.NEXPst = uicontrol(dynparam.h,'Style','text','String','NEXP = ','Units','pixels','Position',[5,32.5,45,20]);
h.DTed = uicontrol(dynparam.h,'Style','edit','String','Time step to compute response history','Units','pixels','Position',[55,10,140,20],'Callback',{@DTed_Callback});
h.DTst = uicontrol(dynparam.h,'Style','text','String','DT =','Units','pixels','Position',[5,7.5,45,20]);

% UI controls for water properties
watprop.h = uipanel('Parent',f.h,'Title','Water Properties','Units','pixels','Position',[410,10,210,60]);
h.ALPHAed = uicontrol(watprop.h,'Style','edit','String','Wave reflection coefficient','Units','pixels','Position',[55,10,140,20],'Callback',{@ALPHAed_Callback});
h.ALPHAst = uicontrol(watprop.h,'Style','text','String','ALPHA =','Units','pixels','Position',[5,7.5,45,20]);

% UI controls for "use own input file"
inpfile.h = uipanel('Parent',f.h,'Title',' (Use own geometry file) ','Units','pixels','Position',[410,251,210,95]);
h.advOptpb = uicontrol(inpfile.h,'Style','pushbutton','String','Define mesh input file*','Units','pixels','Position',[5,40,192.5,30],'Callback',{@inpFilpb_Callback});
h.inpfilest = uicontrol(inpfile.h,'Style','text','String','*Only if automatic mesh generator is not to be used','Units','pixels','Position',[5,5,170,30]);
set(h.inpfilest,'FontAngle','italic');

% UI controls for program control parameters
anaparam.h = uipanel('Parent',f.h,'Title','Program Control Parameters','Units','pixels','Position',[630,401,384,165]);
h.IRESpm = uicontrol(anaparam.h,'Style','popupmenu','String',{'Compute dynamic response','Only perform static analysis and compute vibration properties',},'Value',1,'Position',[65,120,304,20],'Callback',{@IRESpm_Callback});
h.IRESst = uicontrol(anaparam.h,'Style','text','String','    IRES = ','Units','pixels','Position',[15,117.5,45,20]);
h.ICOMBpm = uicontrol(anaparam.h,'Style','popupmenu','String',{'Compute dynamic response only, excluding initial static loads','Combine dynamic response with static loads',},'Value',1,'Position',[65,95,304,20],'Callback',{@ICOMBpm_Callback});
h.ICOMBst = uicontrol(anaparam.h,'Style','text','String',' ICOMB = ','Units','pixels','Position',[15,92.5,45,20]);
h.IGRAVpm = uicontrol(anaparam.h,'Style','popupmenu','String',{'Perform static analysis due to dam weight & hydrostatic pressure','Do not perform static analysis'},'Value',1,'Position',[65,70,304,20],'Callback',{@IGRAVpm_Callback});
h.IGRAVst = uicontrol(anaparam.h,'Style','text','String','IGRAV = ','Units','pixels','Position',[15,67.5,45,20]);
h.IRIGpm = uicontrol(anaparam.h,'Style','popupmenu','String',{'Foundation is flexible, include dam-foundation interaction effects','Foundation is rigid, exclude dam-foundation interaction effects'},'Value',1,'Position',[65,45,304,20],'Callback',{@IRIGpm_Callback});
h.IRIGst = uicontrol(anaparam.h,'Style','text','String','     IRIG = ','Units','pixels','Position',[15,42.5,45,20]);
h.PSPpm = uicontrol(anaparam.h,'Style','popupmenu','String',{'Dam & foundation are in plane stress','Dam & foundation are in plane strain'},'Value',1,'Position',[65,20,304,20],'Callback',{@PSPpm_Callback});
h.PSPst = uicontrol(anaparam.h,'Style','text','String','     PSP =  ','Units','pixels','Position',[15,17.5,45,20]);

% UI control for analysis result options
anaresopt.h = uipanel('Parent',f.h,'Title','Output Options for Post-Processing','Units','pixels','Position',[630,205,384,186]);
h.PRINSTRcb = uicontrol(anaresopt.h,'Style','checkbox','String','Save max and min principal stress contourplots','Value',1,'Units','pixels','Position',[15,140,364,20],'Callback',{@PRINSTRcb_Callback});
h.PRINDSPcb = uicontrol(anaresopt.h,'Style','checkbox','String','Save response history of horizontal crest displacement','Value',1,'Units','pixels','Position',[15,110,364,20],'Callback',{@PRINDSPcb_Callback});
h.PRINMODEcb = uicontrol(anaresopt.h,'Style','checkbox','String','Save vibration frequencies and plot of mode shapes','Value',1,'Units','pixels','Position',[15,80,364,20],'Callback',{@PRINMODEcb_Callback});
h.OPENcb = uicontrol(anaresopt.h,'Style','checkbox','String','Open standard script for post-processing','Value',1,'Units','pixels','Position',[15,50,364,20],'Callback',{@OPENcb_Callback});

% UI control for create EAGD input file
h.crINPpb = uicontrol('Style','pushbutton','String','1. Create Input File','Position',[630,120,384,50],'Callback',{@crINPpb_Callback});
set(h.crINPpb,'FontWeight','Bold','FontSize',14);

% UI control for execution of EAGD
h.runE1Apb = uicontrol('Style','pushbutton','String','2. Run EAGD-84','Position',[630,65,384,50],'Callback',{@runE1Apb_Callback});
set(h.runE1Apb,'FontWeight','Bold','FontSize',14);

% UI control for analysis results
h.obtrespb = uicontrol('Style','pushbutton','String','3. Obtain Analysis Results','Position',[630,10,384,50],'Callback',{@obtrespb_Callback});
set(h.obtrespb,'FontWeight','Bold','FontSize',14);

% 1.2 INITIALIZE THE GUI

% Change units to normalized so components resize automatically
set([f.h,h.dam_mod,h.dam_modst,matprop.h,h.Eced,h.Ecst,h.DENSced,h.DENScst,h.POISced,h.POIScst,h.DAMPced,h.DAMPcst,h.DAMPcst2...
    fndprop.h,h.Efed,h.Efst,h.DENSfed,h.DENSfst,h.DAMPfpm,h.DAMPfst,h.DAMPfst2,h.nBASEed,h.nBASEst,...
    geoprop.h,h.elAed,h.elAst,h.elBed,h.elBst,h.elDed,h.elDst,h.elCed,h.elCst,h.elWLed,h.elWLst,h.L1ed,h.L1st,h.L2ed,h.L2st,h.L3ed,h.L3st,h.L4ed,h.L4st,...
    dynparam.h,h.readEQpb,h.IHVpm,h.IHVst,h.NEVed,h.NEVst,h.NEXPed,h.NEXPst,h.DTed,h.DTst...
    watprop.h,h.ALPHAed,h.ALPHAst...
    anaparam.h,h.IGRAVpm,h.IGRAVst,h.PSPpm,h.PSPst, h.ICOMBpm,h.ICOMBst,h.IRIGpm,h.IRIGst,h.IRESpm,h.IRESst...
    inpfile.h,h.advOptpb,h.inpfilest...
    h.runE1Apb,h.crINPpb...
    anaresopt.h,h.PRINSTRcb,h.OPENcb,h.PRINDSPcb,h.PRINMODEcb,h.obtrespb],'Units','normalized');

% Assign a GUI name to appear in the window title.
set(f.h,'Name','Concrete Gravity Dam Analysis with EAGD-84')
% Move the GUI to the center of the screen.
movegui(f.h,'center')
% Make the GUI visible.
set(f.h,'Visible','on');    

%% 2. DEFINE DEFAULT VALUES

% 2.1 UNIT CONVERSION PARAMETERS
if unitSI 
    ft=1/0.3048 ;                          % m to ft conversion
    ksf=20.8854343 ;                       % MPa to ksf conversion
    ks2ft4=2.204622/ft^4/1000/9.81;        % kg/m3 to k-s2/ft4 conversion
else
    ft=1;                                  % no conversion
    ksf=1;                                 % no conversion
    ks2ft4=1;                              % no conversion
end

% 2.2 INITIAL DEFAULS USER SELECTABLE VARIABLES

% System and analysis variables 
IRES=0;                 % Compute dynamic response
IRIG=0;                 % Flexible/rigid foundation                               
NEV=12;                 % Number of Ritz vectors
IHV = 0;                % Hor/ver ground motion
ICOMB = 0;              % Combine with static loads
IGRAV = 1;              % Perform static analysis
PSP = 0.0;              % Plane stress/strain
DAMPF = 0.01;           % Damping in foundation

% NaN variables (to secure correct user input)
NUMNP=NaN;              % Number of nodal points
NUMEL=NaN;              % Number of elements
NBASE=NaN;              % Nodal points along the base
Spacing=NaN;            % Spacing of nodal point along base
WL=NaN;                 % Height of water level
NPP=NaN;                % "Wet" nodal points
ECm = NaN;              % E-modulus of concrete
DENSCm = NaN;           % Density of concrete
POISC = NaN;            % Poisson ratio of concrete
DAMPC = NaN;            % Damping ratio of concrete
EFm = NaN;              % E-modulus of foundation
DENSFm = NaN;           % Density of foundation
ALPHA = NaN;            % Wave refl. coeff.
NEXP = NaN;             % FFT parameter
DT = NaN;               % Time step for computing dynamic response 
elA = NaN;              % Elev. point A
elB = NaN;              % Elev. point B
elC = NaN;              % Elev. point C
elD = NaN;              % Elev. point D
elWL = NaN;             % Elev. water level
L1 = NaN;               % Length L1
L2 = NaN;               % Lenght L2
L3 = NaN;               % Length L3
L4 = NaN;               % Lenght L4

% Input file variables
inFILE = 0;
fName = '(incl. file extension)';
VAL = [0 0 0 0 0 0];    % To read mesh file

% Ground motion variables
hName = '(incl. file extension)'; vName = '(incl. file extension)';
hNumHead = 0; vNumHead = 0; 
NUMREC=0; dt=0.0; SFAC=1.0;

% Output variables
PRINSTR = 1;
PRINDSP = 1;
PRINMODE = 1;
OPEN = 1;

%% 3. CALLBACKS FOR INPUT

% 3.1 CALLBACKS FOR DAM MATERIAL PROPERTIES
% Ec Callback
    function Eced_Callback(hObject, eventdata, handles)
        ECm = str2double(get(hObject,'string'));
        if isnan(ECm)
            errordlg('You must enter a numeric value','Bad Input','modal')
            uicontrol(hObject)
            return
        end
    end
% DENSc Callback
    function DENSced_Callback(hObject, eventdata, handles)
        DENSCm = str2double(get(hObject,'string'));
        if isnan(DENSCm)
            errordlg('You must enter a numeric value','Bad Input','modal')
            uicontrol(hObject)
            return
        end
    end
% POISc Callback
    function POISced_Callback(hObject, eventdata, handles)
        POISC = str2double(get(hObject,'string'));
        if isnan(POISC)
            errordlg('You must enter a numeric value','Bad Input','modal')
            uicontrol(hObject)
            return
        end
    end
% DAMPc Callback
    function DAMPced_Callback(hObject, eventdata, handles)
        DAMPC = str2double(get(hObject,'string'));
        if isnan(DAMPC)
            errordlg('You must enter a numeric value','Bad Input','modal')
            uicontrol(hObject)
            return
        end
    end

% 3.2 CALLBACKS FOR FOUNDATION ROCK PROPERTIES
% Ef Callback
    function Efed_Callback(hObject, eventdata, handles)
        EFm = str2double(get(hObject,'string'));
        if isnan(EFm)
            errordlg('You must enter a numeric value','Bad Input','modal')
            uicontrol(hObject)
            return
        end
    end
% DENSf Callback
    function DENSfed_Callback(hObject, eventdata, handles)
        DENSFm = str2double(get(hObject,'string'));
        if isnan(DENSFm)
            errordlg('You must enter a numeric value','Bad Input','modal')
            uicontrol(hObject)
            return
        end
    end
% DAMPf Callback
    function DAMPfpm_Callback(source,eventdata)
        str = get(source,'String');
        val = get(source,'Value');
        DAMPF = str2num(str{val});
    end
% nBASE Callback
    function nBASEed_Callback(hObject, eventdata, handles)
        NBASE = str2double(get(hObject,'string'));
        if isnan(NBASE)
            errordlg('You must enter a numeric value','Bad Input','modal')
            uicontrol(hObject)
            return
        elseif NBASE > 16 && IRIG==0
            warndlg('Maximum number of nodal points for which compliance data are are available is 16. Reduce NBASE...','Warning','modal')
            uicontrol(hObject)
            return
        end
    end
     
% 3.3 CALLBACKS FOR GEOMETRIC PROPERTIES OF DAM
% elA Callback
    function elAed_Callback(hObject, eventdata, handles)
        elA = str2double(get(hObject,'string'));
        if isnan(elA)
            errordlg('You must enter a numeric value','Bad Input','modal')
            uicontrol(hObject)
            return
        end
    end
% elB Callback
    function elBed_Callback(hObject, eventdata, handles)
        elB = str2double(get(hObject,'string'));
        if isnan(elB)
            errordlg('You must enter a numeric value','Bad Input','modal')
            uicontrol(hObject)
            return
        end
    end
% elC Callback
    function elCed_Callback(hObject, eventdata, handles)
        elC = str2double(get(hObject,'string'));
        if isnan(elC)
            errordlg('You must enter a numeric value','Bad Input','modal')
            uicontrol(hObject)
            return
        end
    end
% elD Callback
    function elDed_Callback(hObject, eventdata, handles)
        elD = str2double(get(hObject,'string'));
        if isnan(elD)
            errordlg('You must enter a numeric value','Bad Input','modal')
            uicontrol(hObject)
            return
        end
    end
% elWL Callback
    function elWLed_Callback(hObject, eventdata, handles)
        elWL = str2double(get(hObject,'string'));
        if isnan(elWL)
            errordlg('You must enter a numeric value','Bad Input','modal')
            uicontrol(hObject)
            return
        end
    end
% L1 Callback
    function L1ed_Callback(hObject, eventdata, handles)
        L1 = str2double(get(hObject,'string'));
        if isnan(L1)
            errordlg('You must enter a numeric value','Bad Input','modal')
            uicontrol(hObject)
            return
        end
    end
% L2 Callback
    function L2ed_Callback(hObject, eventdata, handles)
        L2 = str2double(get(hObject,'string'));
        if isnan(L2)
            errordlg('You must enter a numeric value','Bad Input','modal')
            uicontrol(hObject)
            return
        end
    end
% L3 Callback
    function L3ed_Callback(hObject, eventdata, handles)
        L3 = str2double(get(hObject,'string'));
        if isnan(L3)
            errordlg('You must enter a numeric value','Bad Input','modal')
            uicontrol(hObject)
            return
        end
    end
% L4 Callback
    function L4ed_Callback(hObject, eventdata, handles)
        L4 = str2double(get(hObject,'string'));
        if isnan(L4)
            errordlg('You must enter a numeric value','Bad Input','modal')
            uicontrol(hObject)
            return
        end
    end

% 3.4 CALLBACKS FOR DYNAMIC RESPONSE PARAMETERS
% IHV Callback
    function IHVpm_Callback(source,eventdata)
        val = get(source,'Value');
        IHV = val-1;
    end
% ALPHA callback
    function ALPHAed_Callback(hObject, eventdata, handles)
        ALPHA = str2double(get(hObject,'string'));
        if isnan(ALPHA)
            errordlg('You must enter a numeric value','Bad Input','modal')
            uicontrol(hObject)
            return
        end
        if ALPHA > 1.00 || ALPHA < 0
            errordlg('ALPHA value must not be greater than 1.00 and must be a positive value','Bad Input','modal')
            uicontrol(hObject)
            return
        end
    end
% NEV callback
    function NEVed_Callback(hObject, eventdata, handles)
    NEV = str2double(get(hObject,'string'));
    if isnan(NEV)
        errordlg('You must enter a numeric value','Bad Input','modal')
        uicontrol(hObject)
        return
    end
end
% NEXP callback
    function NEXPed_Callback(hObject, eventdata, handles)
    NEXP = str2double(get(hObject,'string'));
    if isnan(NEXP)
        errordlg('You must enter a numeric value','Bad Input','modal')
        uicontrol(hObject)
        return
    end
    end
% DT callback
    function DTed_Callback(hObject, eventdata, handles)
    DT = str2double(get(hObject,'string'));
    if isnan(DT)
        errordlg('You must enter a numeric value','Bad Input','modal')
        uicontrol(hObject)
        return
    end
    end
% READ EQ PROPERTIES callback
    function readEQpb_Callback(source,eventdata)
        [IHV hName vName hNumHead vNumHead NUMREC dt SFAC] = GUI_EQdata(IHV,hName,vName,hNumHead,vNumHead,NUMREC,dt,SFAC);
        set(h.IHVpm,'Value',IHV+1);
    end

% 3.5 CALLBACKS FOR PROGRAM CONTROL PARAMETERS
% IRES Callback
    function IRESpm_Callback(source,eventdata)
        str = get(source,'String');
        val = get(source,'Value');
        if val==1; IRES=0; else IRES=1; warndlg('No dynamic analysis selected','Warning','modal'); end
    end
% IGRAV Callback
    function IGRAVpm_Callback(source,eventdata)
        str = get(source,'String');
        val = get(source,'Value');
        if val==1; IGRAV=1; else IGRAV=0; end
    end
% PSP Callback
    function PSPpm_Callback(source,eventdata)
        str = get(source,'String');
        val = get(source,'Value');
        PSP = val-1;
    end
% ICOMB Callback
    function ICOMBpm_Callback(source,eventdata)
        str = get(source,'String');
        val = get(source,'Value');
        ICOMB = val-1;
    end
% IRIG Callback
    function IRIGpm_Callback(source,eventdata)
        val = get(source,'Value');
        IRIG = val - 1; % = 0 for flexible, 1 for rigid
    end

% 3.6 CALLBACKS FOR MESH INPUT FILE
    function inpFilpb_Callback(hObject, eventdata, handles)
        [inFILE fName VAL] = GUI_MeshFile(inFILE,fName,VAL);
        if length(VAL)==6 && any(VAL)
            NUMNP=VAL(1); NUMEL=VAL(2);
            NBASE=VAL(3); Spacing=VAL(4);
            WL=VAL(5); NPP=VAL(6);
        end
    end

% 3.7 CALLBACKS FOR OUTPUT OPTIONS FOR ANALYSIS RESULTS
% Principal stress contourplot checkbox callback
    function PRINSTRcb_Callback(hObject,eventdata)
        if (get(hObject,'Value') == get(hObject,'Max'))
            PRINSTR = 1;
        else
            PRINSTR = 0;
        end
    end
% Opne post-processing file checkbox callback
    function OPENcb_Callback(hObject,eventdata)
        if (get(hObject,'Value') == get(hObject,'Max'))
            OPEN = 1;
        else
            OPEN = 0;
        end
    end
% Response history of horizontal crest displacement checkbox callback
    function PRINDSPcb_Callback(hObject,eventdata)
        if (get(hObject,'Value') == get(hObject,'Max'))
            PRINDSP = 1;
        else
            PRINDSP = 0;
        end
    end
% Mode Shape Checkbox Callback
    function PRINMODEcb_Callback(hObject,eventdata)
        if (get(hObject,'Value') == get(hObject,'Max'))
            PRINMODE = 1;
        else
            PRINMODE = 0;
        end
    end

%% 4. CALLBACKS FOR EXECUTION

% 4.1 CALLBACK FOR CREATION OF INPUT FILE
    function crINPpb_Callback(source,eventdata)

        % Check input parameters
        inpVec = [EFm,DENSFm,DAMPF,ECm,DAMPC,POISC,DENSCm,ALPHA, ...
                  NEXP,NEV,DT,NUMREC,dt];
        if inFILE~=1; inpVec = [inpVec,L1,L2,L3,L4,elA,elB,elD,elC,elWL,NBASE]; end
        checkGM1 = ((IHV==0 || IHV==2) && exist(hName,'file')~=2);
        checkGM2 = ((IHV==1 || IHV==2) && exist(vName,'file')~=2);
        checkINP = (inFILE==1 && exist(fName,'file')~=2);
        
        if any(isnan(inpVec)) 
            errordlg('Some of the input parameters is NaN. Input file cannot be created.','Bad Input','modal'); return
        elseif checkGM1 || checkGM2 
            errordlg(' GM data file not found in directory. Input file cannot be created.','Bad Input','modal'); return
        elseif  checkINP 
            errordlg(' Mesh input file not found in directory. Input file cannot be created.','Bad Input','modal'); return
        end
        
        % Convert material properties to correct units
        EF=EFm*ksf;                                             %Foundation modulus of elasticity in ksf
        EC=ECm*ksf;                                             %Concrete modulus of elasticity in ksf
        DENSF=DENSFm*ks2ft4;                                    %Foundation mass density in k-s2/ft3
        DENSC=DENSCm*ks2ft4;                                    %Concrete mass density k-s2/ft4

        % Run mesh generator or read input file
        if inFILE == 0
            % Create mesh
            [COORD Element WL Spacing NUMNP NUMEL NBASE, ...
             NPP WatNodes BaseNodes] = PRE_createMesh(L1,L2,L3, ...
             L4,elA,elB,elC,elD,elWL,NBASE,ft);
            % Plot mesh, if desired by user
            choice = questdlg('Show plot of generated element mesh?','Plot mesh','Yes','No','Yes');
            switch choice; case 'Yes'; Plot_Mesh(NUMEL,COORD(:,2:3),Element(:,2:5),unitSI); end
        else
            [NUMNP NUMEL NBASE WL NPP Spacing WatNodes BaseNodes ... 
             COORD Element] = PRE_readMesh(NUMNP,NUMEL,NBASE,Spacing,WL,NPP,fName);
        end
        
        % Generate EQ time series in correct format
        [EQArrayH EQArrayV] = PRE_createEQArray(IHV,NUMREC,dt,SFAC,hName,hNumHead,vName,vNumHead);

        % Generate input file
        PRE_writeInput(IRES,ICOMB,IGRAV,IRIG,PSP,EC,POISC,DENSC,DAMPC, ...
         EF,DENSF,DAMPF,ALPHA,NUMNP,NUMEL,NBASE,Spacing,WL,NPP,COORD,Element, ...
         WatNodes,BaseNodes,NEV,NEXP,DT,IHV,NUMREC,dt,EQArrayH,EQArrayV);

        % Ask if input file should be opened
        choice = questdlg('Input file created, EAGD can now be run. Show copy of input file?', ...
        'Inut file created','Yes','No','Yes');
        % Handle response
        switch choice
            case 'Yes'; 
                copyfile('input','input_COPY_NOT_FOR_USE.txt'); 
                winopen('input_COPY_NOT_FOR_USE.txt')
        end
    end

    % 4.2 CALLBACK FOR EXECUTION OF EAGD-84
    function runE1Apb_Callback(source,eventdata)
        % Check that necessary input files exists and execute program
        if exist('input','file') ~= 2; 
            errordlg('Input file not found in directory, aborting','Error','modal')
            error('Input file not found in directory');
        end
        if exist('fort.80','file') ~= 2; 
            errordlg('fort.80 file not found in directory, aborting','Error','modal') 
            error('fort.80 file not found in directory');
        end

        % Close all open files, if any
        fclose all;

        % Run program
        helpdlg('EAGD-84 has started...')
        system('E1A.exe');
        helpdlg('EAGD-84 has completed running')

        % Delete unused FORTRAN files
        if exist('fort.1','file') == 2; delete('fort.1'); end
        if exist('fort.2','file') == 2; delete('fort.2'); end
        if exist('fort.10','file') == 2; delete('fort.10'); end
        if exist('fort.15','file') == 2; delete('fort.15'); end
        if exist('fort.90','file') == 2; delete('fort.90'); end
    
    end

% 4.3 CALLBACK FOR OBTAINING ANALYSIS RESULTS
    function obtrespb_Callback(source,eventdata)
        
        % Run post processor script
        helpdlg('Post-processing started...')
        GUI_POST(unitSI,PRINSTR,PRINDSP,PRINMODE)
        if OPEN
            open StandardPost
        end
        helpdlg('Post-processing complete! Results found in directory: "Analysis Results"')
        
    end
end






