function [IHV hNAME vNAME HnumHEAD VnumHEAD NUMREC dt SFAC] = GUI_EQdata(IHV,hNAME,vNAME,HnumHEAD,VnumHEAD,NUMREC,dt, SFAC)
%-------------------------------------------------------------------------%
% Function to read in EQ data in GUI
%-------------------------------------------------------------------------%
%
% Programming by Arnkjell Loekke
% UCB / NTNU 2013
% email: lokke@stud.ntnu.no
%
%-------------------------------------------------------------------------%
%

% Initialize figure
fEQ.h = figure('Visible','off','MenuBar','none','numbertitle','off','Toolbar','none','Position',[50,300,500,250]);

% Set default values
inHOR=1; inVER=1;
if IHV==0; inVER=0; elseif IHV==1; inHOR=0; end
   
%% 1. UI CONTROLS
% UI controls panels for ground motion parameters
EQArrayH.h = uipanel('Parent',fEQ.h,'Units','pixels','Position',[10,190,480,55]);
EQArrayV.h = uipanel('Parent',fEQ.h,'Units','pixels','Position',[10,130,480,55]);
EQArrayO.h = uipanel('Parent',fEQ.h,'Units','pixels','Position',[10,10,480,115]);

% Horizontal ground motion
h2.inHORcb = uicontrol(EQArrayH.h,'Style','checkbox','String','Horizontal Ground Motion','Value',inHOR,'Units','pixels','Position',[10,30,350,20],'Callback',{@inHORcb_Callback});
h2.inHORst = uicontrol(EQArrayH.h,'Style','text','String','Input file name:','Units','pixels','Position',[206,27.5,100,20]);
h2.inHORed = uicontrol(EQArrayH.h,'Style','edit','String',hNAME,'Units','pixels','Position',[310,30,150,20],'Callback',{@inHORed_Callback});
h2.HnumHEADed = uicontrol(EQArrayH.h,'Style','edit','String',num2str(HnumHEAD),'Units','pixels','Position',[380,5,40,20],'Callback',{@HnumHEADed_Callback});
h2.HnumHEADst = uicontrol(EQArrayH.h,'Style','text','String','Number of header lines in file:','Units','pixels','Position',[217,2.5,150,20]);

% Vertical ground motion
h2.inVERcb = uicontrol(EQArrayV.h,'Style','checkbox','String','Vertical Ground Motion:','Value',inVER,'Units','pixels','Position',[10,30,350,20],'Callback',{@inVERcb_Callback});
h2.inVERst = uicontrol(EQArrayV.h,'Style','text','String','Input file name:','Units','pixels','Position',[206,27.5,100,20]);
h2.inVERed = uicontrol(EQArrayV.h,'Style','edit','String',vNAME,'Units','pixels','Position',[310,30,150,20],'Callback',{@inVERed_Callback});
h2.VnumHEADed = uicontrol(EQArrayV.h,'Style','edit','String',num2str(VnumHEAD),'Units','pixels','Position',[380,5,40,20],'Callback',{@VnumHEADed_Callback});
h2.VnumHEADst = uicontrol(EQArrayV.h,'Style','text','String','Number of header lines in file:','Units','pixels','Position',[217,2.5,150,20]);

% Pushbuttons, DT and NUMREC
h2.dted = uicontrol(EQArrayO.h,'Style','edit','String',num2str(dt),'Units','pixels','Position',[200,85,70,20],'Callback',{@dted_Callback});
h2.dtst = uicontrol(EQArrayO.h,'Style','text','String','Time increment of records, dt:','Units','pixels','Position',[10,82.5,155,20]); 
h2.dt2st = uicontrol(EQArrayO.h,'Style','text','String','(dt, # data points and scale factor must be same for both hor. and vert. ground motion files)','Units','pixels','Position',[280,57.5,170,45]);
set(h2.dt2st,'FontAngle','italic')
h2.NUMRECed = uicontrol(EQArrayO.h,'Style','edit','String',num2str(NUMREC),'Units','pixels','Position',[200,55,70,20],'Callback',{@NUMRECed_Callback});
h2.NUMRECst = uicontrol(EQArrayO.h,'Style','text','String','Number of EQ data points in record:','Units','pixels','Position',[5,52.5,190,20]);
h2.SFACed = uicontrol(EQArrayO.h,'Style','edit','String',num2str(SFAC),'Units','pixels','Position',[200,25,70,20],'Callback',{@SFACed_Callback});
h2.SFACst = uicontrol(EQArrayO.h,'Style','text','String','Scale factor for EQ records:','Units','pixels','Position',[5,22.5,155,20]);
h2.DONEpb = uicontrol(EQArrayO.h,'Style','pushbutton','String','Done','Units','pixels','Position',[350,22.5,110,25],'Callback',{@DONEpb_Callback});
    
% Initialize the GUI
% Change units to normalized so components resize automatically.
set([fEQ.h,EQArrayH.h,EQArrayV.h,EQArrayO.h, ...
     h2.inHORcb,h2.inHORst,h2.inHORed,h2.HnumHEADed,h2.HnumHEADst,h2.SFACed,h2.SFACst, ...
     h2.inVERcb,h2.inVERst,h2.inVERed,h2.VnumHEADed,h2.VnumHEADst,h2.NUMRECed,h2.NUMRECst,h2.dted,h2.dtst,h2.dt2st,h2.DONEpb],'Units','normalized');
% Assign a GUI name to appear in the window title.
set(fEQ.h,'Name','EQ Ground Motion Input Parameters')
% Move the GUI to the center of the screen.
movegui(fEQ.h,'center')
% Make the GUI visible.
set(fEQ.h,'Visible','on');   
    

%% 2. CALLBACKS

% HORIZONTAL GROUND MOTION

% inHORcb callback
function inHORcb_Callback(hObject, eventdata, handles)
    inHOR = get(hObject,'Value');
end
% inHORed callback
function inHORed_Callback(hObject, eventdata, handles)
    hNAME = get(hObject,'string');
    if exist(hNAME,'file') ~= 2
        errordlg('File does not exist','Bad Input','modal');
    else
        set(h2.inHORcb,'Value',1); inHOR=1;     
    end
end
% HnumHEADed callback
function HnumHEADed_Callback(hObject, eventdata, handles)
    HnumHEAD = str2double(get(hObject,'string'));
end

% VERTICAL GROUND MOTION

% inHORcb callback
function inVERcb_Callback(hObject, eventdata, handles)
    inVER = get(hObject,'Value');
end
% inHORed callback
function inVERed_Callback(hObject, eventdata, handles)
    vNAME = get(hObject,'string');
    if exist(vNAME,'file') ~= 2
        errordlg('File does not exist','Bad Input','modal'); 
    else
        set(h2.inVERcb,'Value',1); inVER=1;
    end
end
% HnumHEADed callback
function VnumHEADed_Callback(hObject, eventdata, handles)
    VnumHEAD = str2double(get(hObject,'string'));
end

% OTHER

% dt callback
function dted_Callback(hObject, eventdata, handles)
    dt = str2double(get(hObject,'string'));
end
% NUMRECed callback
function NUMRECed_Callback(hObject, eventdata, handles)
    NUMREC = str2double(get(hObject,'string'));
end
% SFACed callback
function SFACed_Callback(hObject, eventdata, handles)
    SFAC = str2double(get(hObject,'string'));
end

% Save and return callback
function DONEpb_Callback(hObject, eventdata, handles)
    IHV=0; if inVER; IHV=inHOR+1; end
    close
end

% Wait until user has selected option before continuing
uiwait;

end