function GUI_POST(unitSI,PRINSTR,PRINDSP,PRINMODE)
%-------------------------------------------------------------------------%
% Function to perform standard post processing when using GUI
% - function is called from GUI_EAGD
%-------------------------------------------------------------------------%
%
% Programming by Arnkjell Loekke
% UCB / NTNU 2013
% email: lokke@stud.ntnu.no
%
%-------------------------------------------------------------------------%

%% CHECK OUTPUT DIRECTORY
Cur_Dir = cd;
dirName = '\Analysis Results\';
if isdir([Cur_Dir dirName])==0; mkdir([Cur_Dir dirName]); end

%% 1. READ OUTPUT DATA
%unitSI=1; PRINSTR=1;PRINDSP=1;PRINMODE=1;

% Read output file
[NUMNP NUMEL NBASE COORD Element Post] = POST_readOutput;

% Compute conversion factors for units
ft=1; psi=1; uTick1 = '(in psi)'; uTick2 = '(in ft)';
if unitSI==1; ft=0.3048; psi=6.8948/1000; uTick1 = '(in MPa)'; uTick2 = '(in m)'; end

%% 2. PLOT MESH, SAVE VIBRATION PROPERTIES, AND PLOT MODE SHAPES 

% Plot and print dam section element meshing
gcf=Plot_Mesh(NUMEL,COORD,Element,unitSI);
print(gcf,'Element meshing.tif','-dtiff');
movefile('Element meshing.tif','Analysis Results\');

Print_MeshProp(NUMNP,NUMEL,NBASE)
movefile('FEM Properties.txt','Analysis Results\');

% Print natural frequencies to txt file
Print_Frequencies(Post);
movefile('Natural Vibration Frequencies.txt','Analysis Results\');

for modeNUM=1:PRINMODE*min(4,length(Post.Vibration.Freq))
    gcf = Plot_Modeshape(COORD,Element,Post,NUMEL,modeNUM);
    print(gcf,['Mode shape number ',num2str(modeNUM),'.tif'],'-dtiff');
    movefile(['Mode shape number ',num2str(modeNUM),'.tif'],'Analysis Results\');
end

% Check that dynamic response has been computed
if isfield(Post,'IRES')==1; warndlg('Dynamic response has not been computed!'); return; end
    
%% 3. CONTOURPLOTS

% Read fort.3 file
[NUMNP NUMEL Post] = POST_readFort3(Post);

if PRINSTR
    % Extract maximum and minimum principal stresses
    S=Post.PrinStrOA;  
    
    % Contourplot for maximum principal stresses    
    gcf = Plot_Contour(S(:,2),Element,COORD,NUMNP,NUMEL,ft,psi,2);
    title(['Maximum principal stress ',uTick1,' contourplot']);
    xlabel(['Distance from dam heel ',uTick2]);
    ylabel(['Height above dam base ',uTick2]);
    print(gcf,'Maximum principal stress contourplot.tif','-dtiff'); 
    movefile('Maximum principal stress contourplot.tif','Analysis Results\');

    % Counterplot for minimum principal stresses   
    gcf = Plot_Contour(S(:,4),Element,COORD,NUMNP,NUMEL,ft,psi,2);
    title(['Minimum principal stress ',uTick1,' contourplot']);
    xlabel(['Distance from dam heel ',uTick2]);
    ylabel(['Height above dam base ',uTick2]);
    print(gcf,'Minimum principal stress contourplot.tif','-dtiff'); 
    movefile('Minimum principal stress contourplot.tif','Analysis Results\');
end

%% 4. DISPLACEMENT PLOTS
if PRINDSP
    if unitSI==0; ft=12; uTick2 = '(in inches)'; else ft=0.3048*100; uTick2 = '(in cm)'; end
    % Find top left node
    crCo = COORD(COORD(:,2)==max(COORD(:,2)),:); if size(crCo,1)>1; crCo = min(crCo); end
    crNod = find(COORD(:,1)==crCo(1)&COORD(:,2)==crCo(2));
    DOF = crNod(1)*2-1;

    % Plot horizontal crest displacement
    gcf=figure;
    Plot_Disp(DOF,Post,ft)
    title(['Horizontal displacements at dam crest']);
    ylabel(['Displacement ',uTick2]);  
    xlabel('Time (in seconds)');
    print(gcf,'Displacement response at crest.tif','-dtiff');
    movefile('Displacement response at crest.tif','Analysis Results\');
end
