function gcf = Plot_Contour(S,Element,COORD,NUMNP,NUMEL,ft,psi,type)
%-------------------------------------------------------------------------%
% Function to create z-values for contourplot and make plot
%-------------------------------------------------------------------------%
%
% Programming by Arnkjell Loekke
% UCB / NTNU 2013
% email: lokke@stud.ntnu.no
%
%-------------------------------------------------------------------------%

% Extract nodal points
X1=COORD(:,1);
Y1=COORD(:,2);

% Initialize stress vector at nodal points
strNod=zeros(NUMNP,1);
cntNod=zeros(NUMNP,1);

% Compute stresses at nodal points by averaging values at centroids 
% over entire mesh
for el = 1:NUMEL
    elnod = Element(el,:);
    dum1 = zeros(NUMNP,1);
    dum2 = zeros(NUMNP,1);
    dum1(elnod,1) = S(el);
    dum2(elnod,1) = 1;
    cntNod = cntNod + dum2;
    strNod = strNod + dum1;
end 

Z1 = strNod ./ cntNod;

% Compute unique heights and coordinates for heights
nh = unique(Y1);
nrow = length(nh);

for row = nrow:-1:1
    hcur = nh(row);
    Xval = X1(Y1==hcur);
    Xgrd(row,:) = linspace(min(Xval),max(Xval),50);
    Ygrd(row,:) = ones(1,50)*hcur;
end

% Reshape and interpolate to finer grid
X2 = reshape(Xgrd',nrow*50,1);
Y2 = reshape(Ygrd',nrow*50,1);
warning('off','MATLAB:griddata:DuplicateDataPoints');
Z2 = griddata(X1,Y1,Z1,X2,Y2,'v4');

% Reshape into matrix
X = reshape(X2,50,nrow)*ft;
Y = reshape(Y2,50,nrow)*ft;
Z = reshape(Z2,50,nrow)*psi;

% Plotting
gcf=figure;
hold on

% Plot contours
if type==1 % Black white contour-lines
    rng = max(Z2*psi) - min(Z2*psi);
    appspace = rng / 5;
    if ft==1
        grdspace = [5 10 15 20 25 50 75 100 125];
    else
        grdspace = [0.05 0.075 0.1 0.2 0.25 0.3 0.4 0.5 0.75 1 1.25 1.5 2 2.25 2.5 3];
    end
    diff = grdspace / appspace - 1;
    [~, loc] = min(abs(diff));
    space = grdspace(loc); 
    if ft==1; lin= (-1000:space:1000); else lin = (-10:space:10); end
    
    [C h]=contour(X,Y,Z,lin,'LineWidth',0.5);
    clabel(C,h,'FontSize',8,'LabelSpacing',350,'Rotation',0);
    colormap([0 0 0])
else % Filled color contour-plot
    [C h]=contourf(X,Y,Z);
    colormap jet;
    colorbar('vertic')
    
    % Plot mesh on top
    for i=1:NUMEL
        co=COORD(Element(i,:),:);
        l1x=[co(1,1) co(2,1)]*ft; l1y=[co(1,2) co(2,2)]*ft;
        l2x=[co(2,1) co(3,1)]*ft; l2y=[co(2,2) co(3,2)]*ft;
        l3x=[co(3,1) co(4,1)]*ft; l3y=[co(3,2) co(4,2)]*ft;
        l4x=[co(4,1) co(1,1)]*ft; l4y=[co(4,2) co(1,2)]*ft;
        plot(l1x,l1y,'k','LineWidth',0.25); plot(l2x,l2y,'k','LineWidth',0.25);
        plot(l3x,l3y,'k','LineWidth',0.25); plot(l4x,l4y,'k','LineWidth',0.25);
    end
    
end

% Set up boundaries for dam outlines
elYhgt = unique(COORD(:,2));
elnumY = length(elYhgt);
for i = 1:elnumY
    Yco = elYhgt(i);
    Xco =  COORD(COORD(:,2)==Yco);
    Xmax = max(Xco); Xmin = min(Xco);
    pltCo(i,:) = [Xmin Xmax Yco]*ft;
end

% Plot boundaries
plot(pltCo(:,1),pltCo(:,3),'k','LineWidth',1); plot(pltCo(:,2),pltCo(:,3),'k','LineWidth',1);
plot([pltCo(1,1) pltCo(1,2)],[pltCo(1,3) pltCo(1,3)],'k','LineWidth',1); 
plot([pltCo(end,1) pltCo(end,2)],[pltCo(end,3) pltCo(end,3)],'k','LineWidth',1);

% Figure control
xmax=max(X1);
ymax=max(Y1);
axis([0 1.05*xmax 0 1.05*ymax]*ft)
axis equal; axis off;
hold off
