function gcf = Plot_Modeshape(COORD,Element,Post,NUMEL,modeNUM)
%-------------------------------------------------------------------------%
% Function to plot and output mode shape for dam
%-------------------------------------------------------------------------%
%
% Programming by Arnkjell Loekke
% UCB / NTNU 2013
% email: lokke@stud.ntnu.no
%
%-------------------------------------------------------------------------%
%

% Column number to extract
col=modeNUM+1;

% Extract from data structure
mShape = Post.Vibration.Modeshape;
vFreq = Post.Vibration.Freq;

% Compute magnification factor
Mhor = 0.075*COORD(1,2) / mShape(1,col);
Mver = 0.075*COORD(1,2) / mShape(2,col);
if abs(Mhor)<abs(Mver); MAGF=Mhor;
else MAGF=Mver; end

% Natural period of vibration
per=2*pi/vFreq(modeNUM);

% Rearrange mode shape vector
mShape_x=mShape(1:2:end,col)*MAGF;
mShape_y=mShape(2:2:end,col)*MAGF;

% Set up boundaries
elYhgt = unique(COORD(:,2));
elnumY = length(elYhgt);
for i = 1:elnumY
    Yco = elYhgt(i);
    Xco =  COORD(COORD(:,2)==Yco);
    Xmax = max(Xco); Xmin = min(Xco);
    pltCo(i,:) = [Xmin Xmax Yco];
end

% Set up figure
gcf=figure;
hold on

% Plot boundaries
plot(pltCo(:,1),pltCo(:,3),'k'); plot(pltCo(:,2),pltCo(:,3),'k');
plot([pltCo(1,1) pltCo(1,2)],[pltCo(1,3) pltCo(1,3)],'k'); 
plot([pltCo(end,1) pltCo(end,2)],[pltCo(end,3) pltCo(end,3)],'k');

% Loop over all elements to create deformed mode shape
for i=1:NUMEL
    % Undeformed mesh
    co=COORD(Element(i,:),:);
    l1x=[co(1,1) co(2,1)]; l1y=[co(1,2) co(2,2)];
    l2x=[co(2,1) co(3,1)]; l2y=[co(2,2) co(3,2)];
    l3x=[co(3,1) co(4,1)]; l3y=[co(3,2) co(4,2)];
    l4x=[co(4,1) co(1,1)]; l4y=[co(4,2) co(1,2)];
    
    % Deformed mesh
    co = [mShape_x(Element(i,:),:) mShape_y(Element(i,:),:)];
    l1xd=l1x + [co(1,1) co(2,1)]; l1yd=l1y + [co(1,2) co(2,2)];
    l2xd=l2x + [co(2,1) co(3,1)]; l2yd=l2y + [co(2,2) co(3,2)];
    l3xd=l3x + [co(3,1) co(4,1)]; l3yd=l3y + [co(3,2) co(4,2)];
    l4xd=l4x + [co(4,1) co(1,1)]; l4yd=l4y + [co(4,2) co(1,2)];
    plot(l1xd,l1yd,'k'); plot(l2xd,l2yd,'k');
    plot(l3xd,l3yd,'k'); plot(l4xd,l4yd,'k');
end

% Save figure
axis([[-.1 1.1]*COORD(end,1) [-.1 1.1]*COORD(1,2)])
title(['Mode Shape Number ',num2str(modeNUM),', Vibration Period is ',num2str(per,'%3.2f'),' sec']);
axis equal
axis off